@@ -1062,6 +1062,9 @@ func_contains(ESExp *f, int argc, ESExpResult **argv, void *data)
 	} else if (!strcmp(propname, "file_as")) {
 		r = e_sexp_result_new(f, ESEXP_RES_STRING);
 		r->value.string = g_strdup_printf ("(|(displayName=%s*)(sn=%s*)(%s=%s*))", str, str, ldap_attr, str);
+	} else if (g_str_equal (ldap_attr, "displayName")) {
+		r = e_sexp_result_new(f, ESEXP_RES_STRING);
+		r->value.string = g_strdup_printf("(|(displayName=%s*)(sn=%s*)(givenName=%s*))", str, str, str);
 	} else
 		r = e_sexp_result_new(f, ESEXP_RES_UNDEFINED);
 	return r;
@@ -1437,7 +1440,7 @@ build_contact_from_entry (EBookBackendGAL *bl, LDAPMessage *e, GList **existing_
 						}
 						else if (info->prop_type & PROP_TYPE_GROUP) {
 							char *grpattrs[3];
-							int i, view_limit = -1, ldap_error, count;
+							int i, view_limit = -1, ldap_error = LDAP_SUCCESS, count;
 							EDataBookView *book_view;
 							LDAPMessage *result;
 							char **email_values, **cn_values, **member_info;
