@@ -29,6 +29,7 @@
 
 #include <camel/camel-file-utils.h>
 #include <camel/camel-offline-store.h>
+#include <camel/camel-string-utils.h>
 
 #include "camel-stub.h"
 #include "camel-exchange-folder.h"
@@ -39,8 +40,8 @@
 
 #define EXTRACT_FIRST_DIGIT(val) val=strtoul (part, &part, 10);
 #define EXTRACT_DIGIT(val) part++; val=strtoul (part, &part, 10);
-#define EXTRACT_FIRST_STRING(val) len=strtoul (part, &part, 10); part++; val=g_strndup (part, len);
-#define EXTRACT_STRING(val) part++; len=strtoul (part, &part, 10); part++; val=g_strndup (part, len);
+#define EXTRACT_FIRST_STRING(val) len=strtoul (part, &part, 10); if (*part) part++; val=g_strndup (part, len); part+=len;
+#define EXTRACT_STRING(val) if (*part) part++; len=strtoul (part, &part, 10); if (*part) part++; val=g_strndup (part, len); part+=len;
 
 #define d(x)
 
@@ -310,7 +311,7 @@ message_info_to_db (CamelFolderSummary *s, CamelMessageInfo *info)
 
 	mir = CAMEL_FOLDER_SUMMARY_CLASS(parent_class)->message_info_to_db (s, info);
 	if (mir) 
-		mir->bdata = g_strdup_printf ("%d-%s %d-%s", einfo->thread_index ? strlen(einfo->thread_index):0 , einfo->thread_index ? einfo->thread_index : "", einfo->href ? strlen(einfo->href):0, einfo->href ? einfo->href:"");
+		mir->bdata = g_strdup_printf ("%d-%s %d-%s", einfo->thread_index ? (int)strlen(einfo->thread_index):0 , einfo->thread_index ? einfo->thread_index : "", einfo->href ? (int)strlen(einfo->href):0, einfo->href ? einfo->href:"");
 
 	return mir;
 }
@@ -584,7 +585,7 @@ camel_exchange_summary_add_offline (CamelFolderSummary *summary,
 	}
 
 	mi->size = camel_message_info_size(info);
-	mi->uid = g_strdup(uid);
+	mi->uid = camel_pstring_strdup (uid);
 	camel_folder_summary_add (summary, (CamelMessageInfo *)mi);
 }
 
@@ -608,6 +609,6 @@ camel_exchange_summary_add_offline_uncached (CamelFolderSummary *summary,
 	mi = camel_message_info_clone(info);
 
 	/* Set uid and add to summary */
-	mi->uid = g_strdup (uid);
+	mi->uid = camel_pstring_strdup (uid);
 	camel_folder_summary_add (summary, mi);
 }
